import colorama
colorama.init()

def stinRun(message,func):
    print(message + " ... ",end='')
    try:
        func()
    except Exception as e:
        print(u"\u001b[31mFAIL\u001b[0m")
    else:
        print(u"\u001b[32mDONE\u001b[0m")